@@ -6,8 +6,9 @@ Module for managing the climate within a room.
 """
 from __future__ import annotations
 
+from collections.abc import Iterator
 import logging
-from typing import TYPE_CHECKING, Any, Iterator
+from typing import TYPE_CHECKING, Any
 
 from xknx.remote_value import (
     GroupAddressesType,
